@@ -580,8 +580,10 @@ class Provider(AddressProvider):
         "{{street_address}}\n{{postcode}}\n{{city}}",
     )
 
-    def province(self):
+    def administrative_unit(self) -> str:
         return self.random_element(self.provinces)
 
-    def city(self):
+    province = administrative_unit
+
+    def city(self) -> str:
         return self.random_element(self.cities)
