@@ -3,7 +3,7 @@ from .. import Provider as DateTimeProvider
 
 class Provider(DateTimeProvider):
 
-    def day_of_week(self):
+    def day_of_week(self) -> str:
         day = self.date('%w')
         DAY_NAMES = {
             "0": "Senin",
@@ -17,7 +17,7 @@ class Provider(DateTimeProvider):
 
         return DAY_NAMES[day]
 
-    def month_name(self):
+    def month_name(self) -> str:
         month = self.month()
         MONTH_NAMES = {
             "01": "Januari",
