@@ -8,6 +8,8 @@ import tarfile
 import uuid
 import zipfile
 
+from typing import Any, Callable, Dict, List, Optional, Sequence, Set, Tuple, Union
+
 from faker.exceptions import UnsupportedFeature
 
 from .. import BaseProvider
@@ -19,7 +21,7 @@ csv.register_dialect('faker-csv', csv.excel, quoting=csv.QUOTE_ALL)
 
 class Provider(BaseProvider):
 
-    def boolean(self, chance_of_getting_true=50):
+    def boolean(self, chance_of_getting_true: int = 50) -> bool:
         """Generate a random boolean value based on ``chance_of_getting_true``.
 
         :sample size=10: chance_of_getting_true=25
@@ -28,7 +30,7 @@ class Provider(BaseProvider):
         """
         return self.generator.random.randint(1, 100) <= chance_of_getting_true
 
-    def null_boolean(self):
+    def null_boolean(self) -> Optional[bool]:
         """Generate ``None``, ``True``, or ``False``, each with equal probability.
 
         :sample size=15:
@@ -39,7 +41,7 @@ class Provider(BaseProvider):
             -1: False,
         }[self.generator.random.randint(-1, 1)]
 
-    def binary(self, length=(1 * 1024 * 1024)):
+    def binary(self, length: int = (1 * 1024 * 1024)) -> bytes:
         """Generate a random binary blob of ``length`` bytes.
 
         :sample: length=64
@@ -47,7 +49,7 @@ class Provider(BaseProvider):
         blob = [self.generator.random.randrange(256) for _ in range(length)]
         return bytes(blob)
 
-    def md5(self, raw_output=False):
+    def md5(self, raw_output: bool = False) -> Union[bytes, str]:
         """Generate a random MD5 hash.
 
         If ``raw_output`` is ``False`` (default), a hexadecimal string representation of the MD5 hash
@@ -56,12 +58,12 @@ class Provider(BaseProvider):
         :sample: raw_output=False
         :sample: raw_output=True
         """
-        res = hashlib.md5(str(self.generator.random.random()).encode())
+        res: hashlib._Hash = hashlib.md5(str(self.generator.random.random()).encode())
         if raw_output:
             return res.digest()
         return res.hexdigest()
 
-    def sha1(self, raw_output=False):
+    def sha1(self, raw_output: bool = False) -> Union[bytes, str]:
         """Generate a random SHA1 hash.
 
         If ``raw_output`` is ``False`` (default), a hexadecimal string representation of the SHA1 hash
@@ -70,12 +72,12 @@ class Provider(BaseProvider):
         :sample: raw_output=False
         :sample: raw_output=True
         """
-        res = hashlib.sha1(str(self.generator.random.random()).encode())
+        res: hashlib._Hash = hashlib.sha1(str(self.generator.random.random()).encode())
         if raw_output:
             return res.digest()
         return res.hexdigest()
 
-    def sha256(self, raw_output=False):
+    def sha256(self, raw_output: bool = False) -> Union[bytes, str]:
         """Generate a random SHA256 hash.
 
         If ``raw_output`` is ``False`` (default), a hexadecimal string representation of the SHA56 hash
@@ -84,13 +86,14 @@ class Provider(BaseProvider):
         :sample: raw_output=False
         :sample: raw_output=True
         """
-        res = hashlib.sha256(
-            str(self.generator.random.random()).encode())
+        res: hashlib._Hash = hashlib.sha256(str(self.generator.random.random()).encode())
         if raw_output:
             return res.digest()
         return res.hexdigest()
 
-    def uuid4(self, cast_to=str):
+    def uuid4(self,
+              cast_to: Optional[Union[Callable[[uuid.UUID], str], Callable[[uuid.UUID], bytes]]] = str,
+              ) -> Union[bytes, str, uuid.UUID]:
         """Generate a random UUID4 object and cast it to another type if specified using a callable ``cast_to``.
 
         By default, ``cast_to`` is set to ``str``.
@@ -101,18 +104,17 @@ class Provider(BaseProvider):
         :sample: cast_to=None
         """
         # Based on http://stackoverflow.com/q/41186818
-        generated_uuid = uuid.UUID(int=self.generator.random.getrandbits(128), version=4)
+        generated_uuid: uuid.UUID = uuid.UUID(int=self.generator.random.getrandbits(128), version=4)
         if cast_to is not None:
-            generated_uuid = cast_to(generated_uuid)
+            return cast_to(generated_uuid)
         return generated_uuid
 
-    def password(
-            self,
-            length=10,
-            special_chars=True,
-            digits=True,
-            upper_case=True,
-            lower_case=True):
+    def password(self,
+                 length: int = 10,
+                 special_chars: bool = True,
+                 digits: bool = True,
+                 upper_case: bool = True,
+                 lower_case: bool = True) -> str:
         """Generate a random password of the specified ``length``.
 
         The arguments ``special_chars``, ``digits``, ``upper_case``, and ``lower_case`` control
@@ -147,21 +149,25 @@ class Provider(BaseProvider):
             required_tokens) <= length, "Required length is shorter than required characters"
 
         # Generate a first version of the password
-        chars = self.random_choices(choices, length=length)
+        chars: str = self.random_choices(choices, length=length)  # type: ignore
 
         # Pick some unique locations
-        random_indexes = set()
+        random_indexes: Set[int] = set()
         while len(random_indexes) < len(required_tokens):
             random_indexes.add(
                 self.generator.random.randint(0, len(chars) - 1))
 
         # Replace them with the required characters
         for i, index in enumerate(random_indexes):
-            chars[index] = required_tokens[i]
+            chars[index] = required_tokens[i]  # type: ignore
 
         return ''.join(chars)
 
-    def zip(self, uncompressed_size=65536, num_files=1, min_file_size=4096, compression=None):
+    def zip(self,
+            uncompressed_size: int = 65536,
+            num_files: int = 1,
+            min_file_size: int = 4096,
+            compression: Optional[str] = None) -> bytes:
         """Generate a bytes object containing a random valid zip archive file.
 
         The number and sizes of files contained inside the resulting archive can be controlled
@@ -194,17 +200,17 @@ class Provider(BaseProvider):
                 '`uncompressed_size` is smaller than the calculated minimum required size',
             )
         if compression in ['bzip2', 'bz2']:
-            compression = zipfile.ZIP_BZIP2
+            compression_ = zipfile.ZIP_BZIP2
         elif compression in ['lzma', 'xz']:
-            compression = zipfile.ZIP_LZMA
+            compression_ = zipfile.ZIP_LZMA
         elif compression in ['deflate', 'gzip', 'gz']:
-            compression = zipfile.ZIP_DEFLATED
+            compression_ = zipfile.ZIP_DEFLATED
         else:
-            compression = zipfile.ZIP_STORED
+            compression_ = zipfile.ZIP_STORED
 
         zip_buffer = io.BytesIO()
         remaining_size = uncompressed_size
-        with zipfile.ZipFile(zip_buffer, mode='w', compression=compression) as zip_handle:
+        with zipfile.ZipFile(zip_buffer, mode='w', compression=compression_) as zip_handle:
             for file_number in range(1, num_files + 1):
                 filename = self.generator.pystr() + str(file_number)
 
@@ -219,7 +225,11 @@ class Provider(BaseProvider):
                 zip_handle.writestr(filename, data)
         return zip_buffer.getvalue()
 
-    def tar(self, uncompressed_size=65536, num_files=1, min_file_size=4096, compression=None):
+    def tar(self,
+            uncompressed_size: int = 65536,
+            num_files: int = 1,
+            min_file_size: int = 4096,
+            compression: Optional[str] = None) -> bytes:
         """Generate a bytes object containing a random valid tar file.
 
         The number and sizes of files contained inside the resulting archive can be controlled
@@ -283,7 +293,11 @@ class Provider(BaseProvider):
                 file_buffer.close()
         return tar_buffer.getvalue()
 
-    def image(self, size=(256, 256), image_format='png', hue=None, luminosity=None):
+    def image(self,
+              size: Tuple[int, int] = (256, 256),
+              image_format: str = 'png',
+              hue: Optional[Union[int, Sequence[int], str]] = None,
+              luminosity: Optional[str] = None) -> bytes:
         """Generate an image and draw a random polygon on it using the Python Image Library.
         Without it installed, this provider won't be functional. Returns the bytes representing
         the image in a given format.
@@ -305,7 +319,7 @@ class Provider(BaseProvider):
             import PIL.Image
             import PIL.ImageDraw
         except ImportError:
-            raise UnsupportedFeature("`image` requires the `Pillow` python library.")
+            raise UnsupportedFeature("`image` requires the `Pillow` python library.", "image")
 
         (width, height) = size
         image = PIL.Image.new('RGB', size, self.generator.color(hue=hue, luminosity=luminosity))
@@ -323,9 +337,13 @@ class Provider(BaseProvider):
             fobj.seek(0)
             return fobj.read()
 
-    def dsv(self, dialect='faker-csv', header=None,
-            data_columns=('{{name}}', '{{address}}'),
-            num_rows=10, include_row_ids=False, **fmtparams):
+    def dsv(self,
+            dialect: str = 'faker-csv',
+            header: Optional[Sequence[str]] = None,
+            data_columns: Tuple[str, str] = ('{{name}}', '{{address}}'),
+            num_rows: int = 10,
+            include_row_ids: bool = False,
+            **fmtparams: Any) -> str:
         """Generate random delimiter-separated values.
 
         This method's behavior share some similarities with ``csv.writer``. The ``dialect`` and
@@ -382,7 +400,11 @@ class Provider(BaseProvider):
 
         return dsv_buffer.getvalue()
 
-    def csv(self, header=None, data_columns=('{{name}}', '{{address}}'), num_rows=10, include_row_ids=False):
+    def csv(self,
+            header: Optional[Sequence[str]] = None,
+            data_columns: Tuple[str, str] = ('{{name}}', '{{address}}'),
+            num_rows: int = 10,
+            include_row_ids: bool = False) -> str:
         """Generate random comma-separated values.
 
         For more information on the different arguments of this method, please refer to
@@ -398,7 +420,11 @@ class Provider(BaseProvider):
             include_row_ids=include_row_ids, delimiter=',',
         )
 
-    def tsv(self, header=None, data_columns=('{{name}}', '{{address}}'), num_rows=10, include_row_ids=False):
+    def tsv(self,
+            header: Optional[Sequence[str]] = None,
+            data_columns: Tuple[str, str] = ('{{name}}', '{{address}}'),
+            num_rows: int = 10,
+            include_row_ids: bool = False) -> str:
         """Generate random tab-separated values.
 
         For more information on the different arguments of this method, please refer to
@@ -414,7 +440,11 @@ class Provider(BaseProvider):
             include_row_ids=include_row_ids, delimiter='\t',
         )
 
-    def psv(self, header=None, data_columns=('{{name}}', '{{address}}'), num_rows=10, include_row_ids=False):
+    def psv(self,
+            header: Optional[Sequence[str]] = None,
+            data_columns: Tuple[str, str] = ('{{name}}', '{{address}}'),
+            num_rows: int = 10,
+            include_row_ids: bool = False) -> str:
         """Generate random pipe-separated values.
 
         For more information on the different arguments of this method, please refer to
@@ -431,7 +461,7 @@ class Provider(BaseProvider):
         )
 
     def json(self,
-             data_columns: list = None,
+             data_columns: List = None,
              num_rows: int = 10,
              indent: int = None) -> str:
         """
@@ -480,10 +510,10 @@ class Provider(BaseProvider):
             'name': '{{name}}',
             'residency': '{{address}}',
         }
-        data_columns = data_columns if data_columns else default_data_columns
+        data_columns: Union[List, Dict] = data_columns if data_columns else default_data_columns
 
-        def process_list_structure(data: list) -> dict:
-            entry = {}
+        def process_list_structure(data: Sequence[Any]) -> Any:
+            entry: Dict[str, Any] = {}
 
             for name, definition, *arguments in data:
                 kwargs = arguments[0] if arguments else {}
@@ -503,8 +533,8 @@ class Provider(BaseProvider):
                     entry[name] = self._value_format_selection(definition, **kwargs)
             return entry
 
-        def process_dict_structure(data: dict) -> dict:
-            entry = {}
+        def process_dict_structure(data: Union[int, float, bool, Dict[str, Any]]) -> Any:
+            entry: Dict[str, Any] = {}
 
             if isinstance(data, str):
                 return self._value_format_selection(data)
@@ -522,7 +552,7 @@ class Provider(BaseProvider):
 
             return data
 
-        def create_json_structure(data_columns) -> dict:
+        def create_json_structure(data_columns: Union[Dict, List]) -> dict:
             if isinstance(data_columns, dict):
                 return process_dict_structure(data_columns)
 
@@ -603,7 +633,7 @@ class Provider(BaseProvider):
             data.append(''.join(row))
         return '\n'.join(data)
 
-    def _value_format_selection(self, definition, **kwargs):
+    def _value_format_selection(self, definition: str, **kwargs: Any) -> Union[int, str]:
         """
         Formats the string in different ways depending on it's contents.
 
